@@ -17,8 +17,9 @@
  *  Boston, MA 02110-1301, USA.
  */
 
+#include "config.h"
 #include "booktree.h"
-#include "utils.h"
+#include "utils/utils.h"
 
 static void booktree_class_init(BookTreeClass *);
 static void booktree_init(BookTree *);
@@ -31,6 +32,7 @@ static void booktree_add_columns(BookTree *);
 static void booktree_setup_selection(BookTree *);
 static void booktree_populate_tree(BookTree *);
 static void booktree_insert_node(BookTree *, GNode *, GtkTreeIter *);
+static void on_row_activated(BookTree* self, GtkTreePath* path);
 
 /* Signals */
 enum {
@@ -90,29 +92,35 @@ booktree_class_init(BookTreeClass *klass)
                               G_TYPE_FROM_CLASS (klass),
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (BookTreeClass, link_selected),
-                              NULL, 
+                              NULL,
                               NULL,
                               g_cclosure_marshal_VOID__POINTER,
                               G_TYPE_NONE,
-                              1, 
+                              1,
                               G_TYPE_POINTER);
 }
 
 static void
-booktree_init(BookTree *tree)
+booktree_init(BookTree *self)
 {
-        tree->store = gtk_tree_store_new(N_COLUMNS,
-                                         GDK_TYPE_PIXBUF,
-                                         GDK_TYPE_PIXBUF,
-                                         G_TYPE_STRING,
-                                         G_TYPE_POINTER);
-        gtk_tree_view_set_model(GTK_TREE_VIEW (tree),
-                                GTK_TREE_MODEL (tree->store));
-        gtk_tree_view_set_headers_visible(GTK_TREE_VIEW (tree), FALSE);
+	self->store = gtk_tree_store_new(N_COLUMNS,
+			GDK_TYPE_PIXBUF,
+			GDK_TYPE_PIXBUF,
+			G_TYPE_STRING,
+			G_TYPE_POINTER);
+	gtk_tree_view_set_model(GTK_TREE_VIEW (self),
+			GTK_TREE_MODEL (self->store));
+	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW (self), FALSE);
+	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(self), TRUE);
 
-        booktree_create_pixbufs(tree);
-        booktree_add_columns(tree);
-        booktree_setup_selection(tree);
+	booktree_create_pixbufs(self);
+	booktree_add_columns(self);
+	booktree_setup_selection(self);
+
+	g_signal_connect(G_OBJECT(self),
+			"row-activated",
+			G_CALLBACK(on_row_activated),
+			NULL);
 }
 
 static void
@@ -142,9 +150,9 @@ booktree_create_pixbufs(BookTree *tree)
 
         pixbufs = g_new0(BookTreePixbufs, 1);
 
-        pixbufs->pixbuf_closed = gdk_pixbuf_new_from_file(CHMSEE_DATA_DIR "/book-closed.png", NULL);
-        pixbufs->pixbuf_opened = gdk_pixbuf_new_from_file(CHMSEE_DATA_DIR "/book-open.png", NULL);
-        pixbufs->pixbuf_doc = gdk_pixbuf_new_from_file(CHMSEE_DATA_DIR "/helpdoc.png", NULL);
+        pixbufs->pixbuf_closed = gdk_pixbuf_new_from_file(get_resource_path("book-closed.png"), NULL);
+        pixbufs->pixbuf_opened = gdk_pixbuf_new_from_file(get_resource_path("book-open.png"), NULL);
+        pixbufs->pixbuf_doc = gdk_pixbuf_new_from_file(get_resource_path("helpdoc.png"), NULL);
 
         tree->pixbufs = pixbufs;
 }
@@ -187,7 +195,7 @@ booktree_setup_selection(BookTree *tree)
         selection = gtk_tree_view_get_selection(GTK_TREE_VIEW (tree));
         gtk_tree_selection_set_mode(selection, GTK_SELECTION_BROWSE);
 
-        g_signal_connect(selection, 
+        g_signal_connect(selection,
                          "changed",
                          G_CALLBACK (booktree_selection_changed_cb),
                          tree);
@@ -250,8 +258,8 @@ booktree_find_uri_foreach(GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *i
         gtk_tree_model_get(model, iter, COL_LINK, &link, -1);
 
         if (g_str_has_suffix(data->uri, link->uri)) {
-                d(g_debug("data->uri: %s", data->uri));
-                d(g_debug("link->uri: %s", link->uri));
+                g_debug("data->uri: %s", data->uri);
+                g_debug("link->uri: %s", link->uri);
 
                 data->found = TRUE;
                 data->iter = *iter;
@@ -273,7 +281,7 @@ booktree_selection_changed_cb(GtkTreeSelection *selection, BookTree *tree)
                 gtk_tree_model_get(GTK_TREE_MODEL (tree->store),
                                    &iter, COL_LINK, &link, -1);
 
-                d(g_debug("book tree emiting '%s'\n", link->uri));
+                g_debug("book tree emiting '%s'\n", link->uri);
 
                 g_signal_emit(tree, signals[LINK_SELECTED], 0, link);
         }
@@ -314,7 +322,7 @@ booktree_select_uri(BookTree *tree, const gchar *uri)
                                &data);
 
         if (!data.found) {
-                d(g_message("booktree select uri: cannot found data"));
+                g_debug("booktree select uri: cannot found data");
                 return;
         }
 
@@ -368,3 +376,11 @@ booktree_get_selected_book_title(BookTree *tree)
         return link->name;
 }
 
+void on_row_activated(BookTree* self, GtkTreePath* path) {
+	g_return_if_fail(IS_BOOKTREE(self));
+	if(gtk_tree_view_row_expanded(GTK_TREE_VIEW(self), path)) {
+		gtk_tree_view_collapse_row(GTK_TREE_VIEW(self), path);
+	} else {
+		gtk_tree_view_expand_row(GTK_TREE_VIEW(self), path, FALSE);
+	}
+}
